Developer Information — Stylist 0.3.dev1 documentation

# Developer Information

Welcome to the “Stylist” code stye checking tool developer documentation.

If you want to use the tool you may find the User Guide more to your taste.

- Overview
  - Unit Testing
  - Type Hinting
  - Code Style
  - Documentation
- API Documentation
  - stylist
- Create a Development Environment
  - Using a Virtual Environment
- Rules
  - Writing a New Text Rule
  - Writing a Fortran Rule
  - Documenting the Rule
- Collected To-do items

A lot of our process is dictated by the GitHub platform used to host the project. For details about that, such as how change requests are handled, see the project wiki.

## Indices and tables

- Module Index

- Index

- Search Page